@@ -1,7 +1,7 @@
 #! /usr/bin/perl
 
 # ex:ts=8 sw=4:
-# $OpenBSD: Quirks.pm,v 1.748 2019/04/03 15:02:19 danj Exp $
+# $OpenBSD: Quirks.pm,v 1.637 2018/10/09 20:34:40 rsadowski Exp $
 #
 # Copyright (c) 2009 Marc Espie <espie@openbsd.org>
 #
@@ -69,8 +69,6 @@ my $base_exceptions = {
 # 6.2
 	'p5-Test-use-ok' => "$p5/Test/use/ok.pm",
 	'p5-Test-Tester' => "$p5/Test/Tester.pm",
-# 6.5
-	'libelf' => '/usr/lib/libelf.so.2.0',
 };
 
 my $stem_extensions = {
@@ -249,6 +247,23 @@ my $stem_extensions = {
 	'gnome-themes-standard' => 'gnome-themes-extra',
 	'open-cobol' => 'gnucobol',
 	'fanstasque-sans' => 'fantasque-sans',
+	'pecl-chroot' => 'pecl56-chroot',
+	'pecl-geoip' => 'pecl56-geoip',
+	'pecl-http' => 'pecl56-pecl_http',
+	'pecl-imagick' => 'pecl56-imagick',
+	'pecl-libsodium' => 'pecl56-libsodium',
+	'pecl-lzf' => 'pecl56-lzf',
+	'pecl-mailparse' => 'pecl56-mailparse',
+	'pecl-memcache' => 'pecl56-memcache',
+	'pecl-memcached' => 'pecl56-memcached',
+	'pecl-proctitle' => 'pecl56-proctitle',
+	'pecl-propro' => 'pecl56-propro',
+	'pecl-raphf' => 'pecl56-raphf',
+	'pecl-rar' => 'pecl56-rar',
+	'pecl-redis' => 'pecl56-redis',
+	'pecl-ssh2' => 'pecl56-ssh2',
+	'pecl-swish' => 'pecl56-swish',
+	'pecl-uploadprogress' => 'pecl56-uploadprogress',
 	'rope' => 'py-rope',
 	'py-upt-rubygems' => 'upt-rubygems',
 	'pygame' => 'py-game',
@@ -267,65 +282,6 @@ my $stem_extensions = {
 	'sdlmame' => 'mame',
 	'sdlmame-tools' => 'mame',
 	'sdlmess' => 'mame',
-	'suricata-update' => 'suricata',
-# 6.5
-	'ValyriaTear' => 'valyriatear',
-	'apertium-es-ast_NO-PN' => 'apertium-es-ast',
-	'py-pafy' => 'py3-pafy',
-	'py-libmagic' => 'py-magic',
-	'py3-libmagic' => 'py3-magic',
-	'pecl-chroot' => 'pecl71-chroot',
-	'pecl-geoip' => 'pecl71-geoip',
-	'pecl-http' => 'pecl71-pecl_http',
-	'pecl-imagick' => 'pecl71-imagick',
-	'pecl-libsodium' => 'pecl71-libsodium',
-	'pecl-lzf' => 'pecl71-lzf',
-	'pecl-mailparse' => 'pecl71-mailparse',
-	'pecl-memcached' => 'pecl71-memcached',
-	'pecl-proctitle' => 'pecl71-proctitle',
-	'pecl-propro' => 'pecl71-propro',
-	'pecl-raphf' => 'pecl71-raphf',
-	'pecl-rar' => 'pecl71-rar',
-	'pecl-redis' => 'pecl71-redis',
-	'pecl-ssh2' => 'pecl71-ssh2',
-	'pecl56-chroot' => 'pecl71-chroot',
-	'pecl56-geoip' => 'pecl71-geoip',
-	'pecl56-http' => 'pecl71-pecl_http',
-	'pecl56-imagick' => 'pecl71-imagick',
-	'pecl56-libsodium' => 'pecl71-libsodium',
-	'pecl56-lzf' => 'pecl71-lzf',
-	'pecl56-mailparse' => 'pecl71-mailparse',
-	'pecl56-memcached' => 'pecl71-memcached',
-	'pecl56-proctitle' => 'pecl71-proctitle',
-	'pecl56-propro' => 'pecl71-propro',
-	'pecl56-raphf' => 'pecl71-raphf',
-	'pecl56-rar' => 'pecl71-rar',
-	'pecl56-redis' => 'pecl71-redis',
-	'pecl56-ssh2' => 'pecl71-ssh2',
-	'pecl70-chroot' => 'pecl71-chroot',
-	'pecl70-geoip' => 'pecl71-geoip',
-	'pecl70-http' => 'pecl71-pecl_http',
-	'pecl70-imagick' => 'pecl71-imagick',
-	'pecl70-libsodium' => 'pecl71-libsodium',
-	'pecl70-lzf' => 'pecl71-lzf',
-	'pecl70-mailparse' => 'pecl71-mailparse',
-	'pecl70-memcached' => 'pecl71-memcached',
-	'pecl70-proctitle' => 'pecl71-proctitle',
-	'pecl70-propro' => 'pecl71-propro',
-	'pecl70-raphf' => 'pecl71-raphf',
-	'pecl70-rar' => 'pecl71-rar',
-	'pecl70-redis' => 'pecl71-redis',
-	'pecl70-ssh2' => 'pecl71-ssh2',
-	'zh-bg5ps' => 'bg5ps',
-	'zh-bg5pdf' => 'bg5pdf',
-	'wxWidgets-gtk2' => 'wxWidgets-gtk3',
-	'atf-allwinner' => 'arm-trusted-firmware',
-	'u-boot-pinebook' => 'u-boot-aarch64',
-	'suricata-update' => 'suricata',
-	'wireshark-gtk' => 'wireshark',
-	'py-zeroconf' => 'py3-zeroconf',
-	'digikam' => 'digikam-kde4',
-	'apertium-sv-da' => 'apertium-swe-dan',
 };
 
 my $obsolete_reason = {
@@ -868,6 +824,8 @@ my $obsolete_reason = {
 	'xgrab' => 9,
 	'quirc' => 3,
 	'xspread' => 3,
+	'tryton' => 1,
+	'trytond' => 1,
 	'sharity-light' => 6,
 	'py-axiom' => 5,
 	'py-epsilon' => 5,
@@ -942,6 +900,7 @@ my $obsolete_reason = {
 	'banshee' => 3,
 	'mono-zeroconf' => 5,
 	'mono-avahi' => 5,
+	'toad' => 3,
 	'pgp' => 3,
 	'gonzui' => 3,
 # 6.3
@@ -1099,119 +1058,12 @@ my $obsolete_reason = {
 	'corebird' => 3,
 	'py-pcs' => 5,
 	'ifmcstat' => 5,
-	'suricata-update' => 6,
-# 6.5
-	'py-dtopt' => 5,
-	'py3-dtopt' => 5,
-	'memtest86+' => 0,
-	'py-reat' => 5,
-	'dovecot-antispam' => 12,
-	'py-hgtools' => 3,
-	'py3-hgtools' => 3,
-	'py-hgsubversion' => 3,
-	'py-hgnested' => 5,
-	'py-keyczar' => 6,
-	'py-hg-git' => 5,
-	'py-czmq' => 3,
-	'p5-Math-Pari' => 13,
-	'p5-Math-BigInt-Pari' => 13,
-	'p5-Crypt-Random' => 13,
-	'p5-Crypt-DH' => 13,
-	'p5-Crypt-Primes' => 13,
-	'p5-Crypt-RSA' => 13,
-	'p5-Crypt-OpenPGP' => 13,
-	'directoryassistant' => 0,
-	'x-pack' => 3,
-	'libepc' => 5,
-	'dysnomia-en' => 0,
-	'casperjs' => 3,
-	'phantomjs' => 3,
-	'owncloud' => 6,
-	'php-librdf' => 13,
-	'nedi' => 13,
-	'xcache' => 13,
-	'pecl-memcache' => 13,
-	'pecl56-memcache' => 13,
-	'pecl-swish' => 13,
-	'pecl56-swish' => 13,
-	'pecl-uploadprogress' => 13,
-	'pecl56-uploadprogress' => 13,
-	'sickbeard' => 3,
-	'nxssh' => 2,
-	'opennx' => 3,
-	'iaxcomm' => 3,
-	'pinot' => 0,
-	'gaia' => 0,
-	'openafs' => 0,
-	'emerillon' => 3,
-	'mplex' => 5,
-	'gromit' => 0,
-	'discwrapper' => 3,
-	'libhttpseverywhere' => 6,
-	'poppler-qt4' => 3,
-	'ushare' => 3,
-	'ffmpeg2theora' => 6,
-	'p5-WWW-Google-SiteMap' => 3,
-	'p5-YAML-Perl' => 3,
-	'py-nevow' => 5,
-	'gupnp-ui' => 3,
-	'suricata-update' => 6,
-	'exploitdb-papers' => 1,
-	'nautilus-sendto' => 3,
-	'libstrophe' => 5,
-	'ghostview' => 2,
-	'libcudf' => 7,
-	'ocaml-cudf' => 7,
-	'ocaml-cmdliner' => 7,
-	'ocaml-cppo' => 7,
-	'ocaml-dose' => 7,
-	'ocaml-extlib' => 7,
-	'ocaml-jsonm' => 7,
-	'ocaml-re' => 7,
-	'omake' => 7,
-	'ounit' => 7,
-	'obc' => 5,
-	'mlbviewer' => 3,
-	'upsd' => 3,
-	'vagalume' => 0,
-	'ocaml-uutf' => 7,
-	'xbat' => 3,
-	'xripple' => 3,
-	'sliderule' => 3,
-	'swisswatch' => 3,
-	'xaniroc' => 3,
-	'xmascot' => 3,
-	'xmold' => 3,
-	'xsnow' => 3,
-	'xtattr' => 3,
-	'ruby25-akami' => 1,
-	'ruby25-gyoku' => 1,
-	'ruby25-httpclient' => 1,
-	'ruby25-httpi' => 1,
-	'ruby25-nori' => 1,
-	'ruby25-savon' => 1,
-	'ruby25-sonos' => 1,
-	'ruby25-wasabi' => 1,
-	'linuxdoc' => 6,
-	'luna' => 3,
-	'rsynth' => 3,
-	'agm' => 3,
-	'connect4' => 3,
-	'xchomp' => 3,
-	'xdeblock' => 3,
-	'xzip' => 3,
-	'jive' => 3,
-	'compface' => 3,
-	'mirror' => 3,
-	'dclock' => 3,
-	'xfishtank' => 3,
-	'mpeg_play' => 6,
 };
 
 # reasons for obsolete packages
 my @msg = (
 	"ancient software that doesn't work", #0
-	"no benefit to being packaged", #1
+	"web application with no benefit being packaged", #1
 	"no longer maintained and full of security holes", #2
 	"no longer maintained upstream", #3
 	"superseded by base component", #4
@@ -1222,8 +1074,6 @@ my @msg = (
 	"256 colors only, suggest scrot or xwd", #9
 	"has been replaced by opendkim", #10
 	"no longer packageable", #11
-	"replace with IMAPSieve, see https://wiki.dovecot.org/HowTo/AntispamWithSieve", #12
-	"has a dependency on obsolete software", #13
 );
 
 # ->is_base_system($handle, $state):
@@ -1264,7 +1114,7 @@ sub filter_obsolete
 	for my $pkgname (@in) {
 		my $stem = OpenBSD::PackageName::splitstem($pkgname);
 		my $reason = $obsolete_reason->{$stem};
-		$reason = 3 if (!defined $reason && $pkgname =~ m/^(drupal(-6|6-)|ruby(19|2[0-3])-|ruby-[^0-9])/);
+		$reason = 3 if (!defined $reason && $pkgname =~ m/^(drupal(-6|6-)|ruby(19|2[0-2])-|ruby-[^0-9])/);
 		if (defined $reason) {
 			$state->say("Obsolete package: #1 (#2)", $pkgname, 
 			    $msg[$reason]);
@@ -1302,53 +1152,29 @@ sub tweak_search
 # list of
 #   cat/path => badspec
 my $cve = {
-	'archivers/cabextract' => 'cabextract-<1.8',
-	'archivers/libmspack' => 'libmspack-<0.8alpha',
-	'archivers/p5-Archive-Zip' => 'p5-Archive-Zip-<1.64',
 	'audio/flac' => 'flac-<1.3.0p1',
-	'databases/sqlite3' => 'sqlite3-<3.25.3',
-	'databases/mariadb,-main' => 'mariadb-client-<10.0.38',
-	'databases/mariadb,-server' => 'mariadb-server-<10.0.38',
-	'databases/postgresql,-main' => 'postgresql-client-<10.6',
-	'databases/postgresql,-server' => 'postgresql-server-<10.6',
+	'databases/mariadb,-main' => 'mariadb-client-<10.0.36',
+	'databases/mariadb,-server' => 'mariadb-server-<10.0.36',
+	'databases/postgresql,-main' => 'postgresql-client-<10.5',
+	'databases/postgresql,-server' => 'postgresql-server-<10.5',
 	'devel/git,-main' => 'git-<2.19.1',
 	'devel/git,-svn' => 'git-svn-<2.19.1',
 	'devel/git,-x11' => 'git-x11-<2.19.1',
-	'devel/jenkins/devel' => 'jenkins-<2.154',
-	'devel/jenkins/stable' => 'jenkins-<2.138.4',
-	'devel/libgit2/libgit2' => 'libgit2-<0.27.7',
 	'devel/mercurial,-main' => 'mercurial-<4.5.3p1',
 	'devel/mercurial,-x11' => 'mercurial-x11-<4.5.3p1',
 	'devel/pcre' => 'pcre-<8.38',
-	'devel/sdl2-image' => 'sdl2-image-<2.0.4',
 	'graphics/tiff' => 'tiff-<4.0.4beta',
 	'lang/php/5.6,-main' => 'php-<5.6.38',
 	'lang/php/7.0,-main' => 'php->7.0,<7.0.32',
 	'lang/php/7.1,-main' => 'php->7.1,<7.1.22',
-	'lang/php/7.2,-main' => 'php->7.2,<7.2.10',
-	'lang/python/2.7,-main' => 'python->2.7,<2.7.16',
-	'lang/ruby/2.3,-main' => 'ruby-<2.3.8',
-	'lang/ruby/2.4,-main' => 'ruby->2.4,<2.4.5p2',
-	'lang/ruby/2.5,-main' => 'ruby->2.5,<2.5.5',
-	'lang/ruby/2.6,-main' => 'ruby->2.6,<2.6.2',
-	'mail/dovecot,-main' => 'dovecot-<2.3.4.1',
+	'lang/php/7.2,-main' => 'php-7.2->7.2,<7.2.10',
 	'mail/exim' => 'exim-<4.83',
 	'mail/p5-Mail-SpamAssassin' => 'p5-Mail-SpamAssassin-<3.4.2',
-	'mail/roundcubemail' => 'roundcubemail-<1.3.8',
-	'math/hdf5' => 'hdf5-<1.8.21',
-	'multimedia/libquicktime' => 'libquicktime-<1.2.4p13',
-	'net/curl' => 'curl-<7.64.0',
-	'net/haproxy' => 'haproxy-<1.8.17',
-	'net/icecast' => 'icecast-<2.4.4',
-	'net/isc-bind' => 'isc-bind-<9.11.5pl4v0',
-	'net/libssh2' => 'libssh2-<1.8.2',
+	'mail/roundcubemail' => 'roundcubemail-<1.3.7',
+	'net/curl' => 'curl-<7.61.1',
+	'net/isc-bind' => 'isc-bind-<9.11.4pl2',
 	'net/lldpd' => 'lldpd-<0.7.18p0',
-	'net/mosquitto' => 'mosquitto-<1.5.6',
 	'net/ntp' => 'ntp-<4.2.8pl7',
-	'net/openconnect' => 'openconnect-<8.01',
-	'net/powerdns,-main' => 'powerdns-<4.1.5',
-	'net/powerdns,-mysql' => 'powerdns-mysql-<4.1.5',
-	'net/powerdns,-pgsql' => 'powerdns-pgsql-<4.1.5',
 	'net/samba,-main' => 'samba-<4.8.4',
 	'net/tinc' => 'tinc-<1.0.35v0',
 	'net/transmission,-gtk' => 'transmission-gtk-<2.84',
@@ -1359,31 +1185,19 @@ my $cve = {
 	'net/wireshark,-text' => 'tshark-<2.6.3',
 	'print/cups,-main' => 'cups-<1.7.4',
 	'security/clamav' => 'clamav-<0.100.2',
-	'security/polarssl' => 'mbedtls-<2.14.1',
 	'shells/bash' => 'bash-<4.3.27',
-	'sysutils/ansible,-main' => 'ansible-<2.7.1',
 	'sysutils/mcollective' => 'mcollective-<2.5.3',
 	'telephony/asterisk,-main' => 'asterisk-<13.23.1',
 	'www/apache-httpd,-main' => 'apache-httpd-<2.4.35',
 	'www/bozohttpd' => 'bozohttpd-<20130711p0',
 	'www/chromium' => 'chromium-<69.0.3497.100',
-	'www/drupal7/core7' => 'drupal->=7.0,<7.60',
+	'www/drupal7/core7' => 'drupal->=7.0,<7.59',
 	'www/drupal7/theme-newsflash' => 'drupal7-theme-newsflash-<2.5',
-	'www/hiawatha' => 'hiawatha-<10.8.4',
 	'www/iridium' => 'iridium-<2018.5.67',
 	'www/mozilla-firefox' => 'firefox-<62.0.2p0',
-	'www/nginx' => 'nginx-<1.4.1',
 	'www/p5-CGI-Application' => 'p5-CGI-Application-<4.50p0',
-	'www/p5-Catalyst-Plugin-Static-Simple' => 'p5-Catalyst-Plugin-Static-Simple-<0.36',
-	'www/py-django/lts' => 'py-django-lts-<1.11.19',
-	'www/py-django/stable' => 'py-django-<2.1.6',
-	'www/py-requests' => 'py-requests-<2.20.0',
-	'www/py-requests,python3' => 'py3-requests-<2.20.0',
-	'www/ruby-rack,ruby24' => 'ruby24-rack-<2.0.6',
-	'www/ruby-rack,ruby25' => 'ruby25-rack-<2.0.6',
 	'www/webkitgtk4' => 'webkitgtk4-<2.20.5',
 	'x11/gnome/gdm' => 'gdm-<3.28.3',
-	'x11/rdesktop' => 'rdesktop-<1.8.4',
 };
 # please maintain sort order in above $cve list, future updates need to
 # replace existing entries
@@ -1396,6 +1210,8 @@ for my $sub (qw(apache cgi dbg bz2 curl dba gd gmp intl imap ldap mysqli
     odbc pcntl pdo_mysql pdo_odbc pdo_pgsql pdo_sqlite pgsql pspell
     shmop soap snmp sqlite3 pdo_dblib tidy xmlrpc xsl zip mysql
     sybase_ct mssql mcrypt)) {
+	$cve->{"lang/php/5.6,-$sub"} = "php-$sub-<5.6.38";
+	$cve->{"lang/php/7.0,-$sub"} = "php-$sub->7.0,<7.0.32";
 	$cve->{"lang/php/7.1,-$sub"} = "php-$sub->7.1,<7.1.22";
 	$cve->{"lang/php/7.2,-$sub"} = "php-$sub->7.2,<7.2.10";
 }
